StaticExecutionGraph

Struct StaticExecutionGraph 

pub struct StaticExecutionGraph { /* private fields */ }
ExecutionGraph implementation which generates all stages on job submission time

Implementations

Source

impl StaticExecutionGraph

pub fn new( scheduler_id: &str, job_id: &JobId, job_name: &str, session_id: &str, plan: Arc<dyn ExecutionPlan>, queued_at: u64, session_config: Arc<SessionConfig>, planner: &mut dyn DistributedPlanner, logical_plan: Option<String>, ) -> Result<Self>

Creates a new ExecutionGraph from a physical execution plan.

This will use the DistributedPlanner to break the plan into stages and build the DAG structure needed for distributed execution.